@@ -1,15 +1,13 @@
 import os
+import sys
 from types import FunctionType
 
 from werkzeug.exceptions import NotFound
-from werkzeug.middleware.shared_data import SharedDataMiddleware
 from werkzeug.routing import Map, Rule
-from werkzeug.serving import run_simple
 
-from .app_context import AppContext
-from .http import HttpServerError, HttpNotFound, HttpResponse, HttpRequest
+from .context import AppContext
+from .http import HttpServerError, HttpNotFound, HttpRequest
 from .routes.router import Router
-from .util.func_util import FunctionDescription
 
 
 class App:
@@ -18,20 +16,32 @@ class App:
                  app_root: str,
                  api_prefix='api',
                  debug_mode=False,
-                 append_slash=False
+                 append_slash=False,
+                 strict_mode=False,
+                 api_page_enabled=None,
+                 api_page_name: str = None,
+                 api_page_expanded=False,
+                 api_page_cache=True,
+                 api_page_addition=None
                  ):
         """
 
         :param app_id: 全局的唯一 id, 用于标识一个APP。可以通过 AppContext.get(id) 获取应用的 Context
-        :param app_root:
-        :param api_prefix:
-        :param debug_mode:
-        :param append_slash:
+        :param app_root: 应用的根目录
+        :param api_prefix: API接口URL前缀
+        :param debug_mode: 是否启用调试模式
+        :param append_slash: 是否在URL末尾使用 / 符号
+        :param strict_mode: 是否启用严格模式。在严格模式下，不允许在请求时携带未声明的参数
+        :param api_page_enabled: 只否启用接口页面
+        :param api_page_name: 接口页面名称
+        :param api_page_expanded: 是否展示接口列表
+        :param api_page_cache: 是否缓存接口数据
+        :param api_page_addition: 接口页面上要展示的接口的附加信息函数，其接收一个 dict 类型的参数 route_info
         """
-
         self.id = app_id
-        self.context = AppContext(self.id, app_root, debug_mode, append_slash)
-        self.dev_options = {}
+        self.context = AppContext(self.id, app_root, debug_mode, append_slash,
+                                  strict_mode, api_page_enabled, api_page_name,
+                                  api_page_expanded, api_page_cache, api_page_addition)
 
         self.api_prefix = api_prefix
         self.router = Router(self.context)
@@ -55,21 +65,15 @@ class App:
             request = HttpRequest(environ, self.context.app_id)
             adapter = self.url_map.bind_to_environ(environ)
 
-            # 仅在调试时重定向
-            if self.context.DEBUG and request.path == '/':
-                response = HttpResponse(status=302, headers={
-                    'Location': '/' + self.api_prefix
-                })
+            endpoint, values = adapter.match()
+            if endpoint == 'api_list':
+                response = self.router.api_list(request)
+            elif endpoint == 'entry_only':
+                response = self.router.dispatch(request, values['entry'])
+            elif endpoint in self.custom_url_map:
+                response = self.custom_url_map[endpoint](request, **values)
             else:
-                endpoint, values = adapter.match()
-                if endpoint == 'api_list':
-                    response = self.router.api_list(request)
-                elif endpoint == 'entry_only':
-                    response = self.router.dispatch(request, values['entry'])
-                elif endpoint in self.custom_url_map:
-                    response = self.custom_url_map[endpoint](request, **values)
-                else:
-                    response = HttpNotFound()
+                response = HttpNotFound()
         except Exception as e:
             if isinstance(e, NotFound):
                 response = HttpNotFound()
@@ -95,22 +99,10 @@ class App:
         if not self.context.static_map:
             return self.handle_wsgi_request(environ, start_response)
 
+        from werkzeug.middleware.shared_data import SharedDataMiddleware
         return SharedDataMiddleware(self.handle_wsgi_request, self.context.static_map)(
             environ, start_response)
 
-    def close(self):
-        for middleware in self.context.middlewares:
-            middleware.dispose()
-
-    def update_debug_mode(self, debug_mode: bool):
-        """
-        更新调试模式
-        :param debug_mode:
-        :return:
-        """
-        self.context.update_debug_mode(debug_mode)
-        return self
-
     def startup(self, host='127.0.0.1', port=9127, threaded=True, **kwargs):
         """
         开发时使用的服务器，一般来说，应仅用于开发
@@ -121,6 +113,8 @@ class App:
         :return:
         """
         from restfx.util import helper
+        from werkzeug.serving import run_simple
+
         debug_mode = self.context.DEBUG
 
         if debug_mode:
@@ -128,8 +122,31 @@ class App:
         else:
             helper.print_meta('dev-server')
 
+        # 检查启动参数
+        argv = sys.argv
+        if len(argv) > 1:
+            server_arg = argv[1].split(':')
+            if len(server_arg) == 1:
+                self.context.logger.warning('Invalid startup argument "%s" (ignored):' % argv[1])
+            else:
+                host = server_arg[0]
+                port = int(server_arg[1])
+
+        # 检查环境变量
+        env_host = os.environ.get('RESTFX_HOST')
+        env_port = os.environ.get('RESTFX_PORT')
+
+        if env_host is not None:
+            host = env_host
+        if env_port is not None:
+            port = int(env_port)
+
+        if self.context.api_page_enabled:
+            print(' * Table of APIs: http://%s:%s/%s%s' % (
+                host, port, self.api_prefix, '/' if self.context.append_slash else ''
+            ))
+
         run_simple(host, port, self, use_debugger=debug_mode, use_reloader=debug_mode, threaded=threaded, **kwargs)
-        self.close()
 
     def collect(self, *global_classes):
         """
@@ -206,7 +223,7 @@ class App:
                 self.context.logger.warning(
                     'Invalid prefix of static map, it should start with "/": %s' % prefix)
                 continue
-            if prefix.lower() == '/restfx_assets_for_dev':
+            if prefix.lower() == '/internal_assets':
                 self.context.logger.warning(
                     'The prefix of static map is reserved, pick another one please: %s' % prefix)
                 continue
@@ -239,6 +256,8 @@ class App:
         :param handler:
         :return:
         """
+        from .util.func_util import FunctionDescription
+
         rid = '%s#%s' % (path, method.lower())
         if rid in self.router.production_routes:
             self.context.logger.warning('%s %s exists' % (method, path))
@@ -267,13 +286,24 @@ class App:
         :param middlewares: 中间件实例列表
         :return:
         """
+        from restfx.middleware import MiddlewareBase
+
         for middleware in middlewares:
+            assert isinstance(middleware, MiddlewareBase)
             self.context.middlewares.append(middleware)
             self.context.reversed_middlwares.insert(0, middleware)
         return self
 
-    def set_dev_options(self, **kwargs):
-        """
-        """
-        self.context.dev_options.update(**kwargs)
+    def inject(self, **kwargs):
+        self.context.injections.update(**kwargs)
         return self
+
+    @staticmethod
+    def get(app_id: str):
+        """
+
+        :param app_id:
+        :return:
+        :rtype: AppContext
+        """
+        return AppContext.get(app_id)
